==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/PeopleArrowsLeftRight.md <==
# PeopleArrowsLeftRight


```text
fontawesome-6/Solid/PeopleArrowsLeftRight
```

```text
include('fontawesome-6/Solid/PeopleArrowsLeftRight')
```



| Illustration | PeopleArrowsLeftRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PeopleArrowsLeftRight.png) | ![illustration for PeopleArrowsLeftRight](../../fontawesome-6/Solid/PeopleArrowsLeftRight.Local.png) |




## PeopleArrowsLeftRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PeopleArrowsLeftRight
include('fontawesome-6/Solid/PeopleArrowsLeftRight')

' renders the element
PeopleArrowsLeftRight('PeopleArrowsLeftRight', 'People Arrows Left Right', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PeopleArrowsLeftRight
include('fontawesome-6/Solid/PeopleArrowsLeftRight')

' renders the element
PeopleArrowsLeftRight('PeopleArrowsLeftRight', 'People Arrows Left Right', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/fontawesome-6/Solid/PeopleArrowsLeftRight.md <==
# PeopleArrowsLeftRight


```text
fontawesome-6/Solid/PeopleArrowsLeftRight
```

```text
include('fontawesome-6/Solid/PeopleArrowsLeftRight')
```



| Illustration | PeopleArrowsLeftRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PeopleArrowsLeftRight.png) | ![illustration for PeopleArrowsLeftRight](../../fontawesome-6/Solid/PeopleArrowsLeftRight.Local.png) |




## PeopleArrowsLeftRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PeopleArrowsLeftRight
include('fontawesome-6/Solid/PeopleArrowsLeftRight')

' renders the element
PeopleArrowsLeftRight('PeopleArrowsLeftRight', 'People Arrows Left Right', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PeopleArrowsLeftRight
include('fontawesome-6/Solid/PeopleArrowsLeftRight')

' renders the element
PeopleArrowsLeftRight('PeopleArrowsLeftRight', 'People Arrows Left Right', 'an optional tech label', 'an optional description')
@enduml
```
